@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004 Ian Berry                                            |
+ | Copyright (C) 2004-2010 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,14 +13,12 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | cacti: a php-based graphing solution                                    |
+ | Cacti: The Complete RRDTool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
- | Most of this code has been designed, written and is maintained by       |
- | Ian Berry. See about.php for specific developer credit. Any questions   |
- | or comments regarding this code should be directed to:                  |
- | - iberry@raxnet.net                                                     |
+ | This code is designed, written, and maintained by the Cacti Group. See  |
+ | about.php and/or the AUTHORS file for specific developer information.   |
  +-------------------------------------------------------------------------+
- | - raXnet - http://www.raxnet.net/                                       |
+ | http://www.cacti.net/                                                   |
  +-------------------------------------------------------------------------+
 */
 
@@ -120,6 +118,9 @@ function form_save() {
 			$save["local_graph_id"] = 0;
 			$save["task_item_id"] = form_input_validate($_POST["task_item_id"], "task_item_id", "", true, 3);
 			$save["color_id"] = form_input_validate((isset($item["color_id"]) ? $item["color_id"] : $_POST["color_id"]), "color_id", "", true, 3);
+			/* if alpha is disabled, use invisible_alpha instead */
+			if (!isset($_POST["alpha"])) {$_POST["alpha"] = $_POST["invisible_alpha"];}
+			$save["alpha"] = form_input_validate((isset($item["alpha"]) ? $item["alpha"] : $_POST["alpha"]), "alpha", "", true, 3);
 			$save["graph_type_id"] = form_input_validate((isset($item["graph_type_id"]) ? $item["graph_type_id"] : $_POST["graph_type_id"]), "graph_type_id", "", true, 3);
 			$save["cdef_id"] = form_input_validate($_POST["cdef_id"], "cdef_id", "", true, 3);
 			$save["consolidation_function_id"] = form_input_validate((isset($item["consolidation_function_id"]) ? $item["consolidation_function_id"] : $_POST["consolidation_function_id"]), "consolidation_function_id", "", true, 3);
@@ -135,7 +136,7 @@ function form_save() {
 					graph_template_input.id,
 					graph_template_input.name,
 					graph_templates_item.task_item_id
-					from graph_template_input,graph_template_input_defs,graph_templates_item
+					from (graph_template_input,graph_template_input_defs,graph_templates_item)
 					where graph_template_input.id=graph_template_input_defs.graph_template_input_id
 					and graph_template_input_defs.graph_template_item_id=graph_templates_item.id
 					and graph_template_input.graph_template_id=" . $save["graph_template_id"] . "
@@ -271,7 +272,7 @@ function item_remove() {
 	/* delete the graph item input if it is empty */
 	$graph_item_inputs = db_fetch_assoc("select
 		graph_template_input.id
-		from graph_template_input,graph_template_input_defs
+		from (graph_template_input,graph_template_input_defs)
 		where graph_template_input.id=graph_template_input_defs.graph_template_input_id
 		and graph_template_input.graph_template_id=" . $_GET["graph_template_id"] . "
 		and graph_template_input_defs.graph_template_item_id=" . $_GET["id"] . "
@@ -298,7 +299,7 @@ function item_edit() {
 
 	$header_label = "[edit graph: " . db_fetch_cell("select name from graph_templates where id=" . $_GET["graph_template_id"]) . "]";
 
-	html_start_box("<strong>Graph Template Items</strong> $header_label", "98%", $colors["header"], "3", "center", "");
+	html_start_box("<strong>Graph Template Items</strong> $header_label", "100%", $colors["header"], "3", "center", "");
 
 	if (!empty($_GET["id"])) {
 		$template_item = db_fetch_row("select * from graph_templates_item where id=" . $_GET["id"]);
@@ -319,7 +320,7 @@ function item_edit() {
 	$struct_graph_item["task_item_id"]["sql"] = "select
 		CONCAT_WS('',data_template.name,' - ',' (',data_template_rrd.data_source_name,')') as name,
 		data_template_rrd.id
-		from data_template_data,data_template_rrd,data_template
+		from (data_template_data,data_template_rrd,data_template)
 		where data_template_rrd.data_template_id=data_template.id
 		and data_template_data.data_template_id=data_template.id
 		and data_template_data.local_data_id=0
@@ -341,7 +342,7 @@ function item_edit() {
 		$graph_item_input_fields = db_fetch_assoc("select
 			graph_template_input.id,
 			graph_template_input.column_name
-			from graph_template_input,graph_template_input_defs
+			from (graph_template_input,graph_template_input_defs)
 			where graph_template_input.id=graph_template_input_defs.graph_template_input_id
 			and graph_template_input.graph_template_id=" . $_GET["graph_template_id"] . "
 			and graph_template_input_defs.graph_template_item_id=" . $_GET["id"] . "
@@ -349,7 +350,7 @@ function item_edit() {
 
 		if (sizeof($graph_item_input_fields) > 0) {
 		foreach ($graph_item_input_fields as $field) {
-			$form_array{$field["column_name"]}["friendly_name"] .= " [<a href='graph_templates_inputs.php?action=input_edit&id=" . $field["id"] . "&graph_template_id=" . $_GET["graph_template_id"] . "'>Field Not Templated</a>]";
+			$form_array{$field["column_name"]}["friendly_name"] .= " [<a href='" . htmlspecialchars("graph_templates_inputs.php?action=input_edit&id=" . $field["id"] . "&graph_template_id=" . $_GET["graph_template_id"]) . "'>Field Not Templated</a>]";
 		}
 		}
 	}
@@ -370,6 +371,36 @@ function item_edit() {
 	form_hidden_box("_graph_type_id", (isset($template_item) ? $template_item["graph_type_id"] : "0"), "");
 	form_hidden_box("_task_item_id", (isset($template_item) ? $template_item["task_item_id"] : "0"), "");
 	form_hidden_box("save_component_item", "1", "");
+	form_hidden_box("invisible_alpha", $form_array["alpha"]["value"], "FF");
+	form_hidden_box("rrdtool_version", read_config_option("rrdtool_version"), "");
 
 	form_save_button("graph_templates.php?action=template_edit&id=" . $_GET["graph_template_id"]);
+
+//Now we need some javascript to make it dynamic
+?>
+<script language="JavaScript">
+
+dynamic();
+
+function dynamic() {
+	//alert("RRDTool Version is '" + document.getElementById('rrdtool_version').value + "'");
+	//alert("Color is '" + document.getElementById('color_id').value + "'");
+	document.getElementById('alpha').disabled=true;
+	if ((document.getElementById('rrdtool_version').value != 'rrd-1.0.x') &&
+		(document.getElementById('color_id').value != 0)) {
+		document.getElementById('alpha').disabled=false;
+	}
 }
+
+function changeColorId() {
+	//alert("Selected Color Index is '" + document.getElementById('color_id').selectedIndex + "'");
+	if ((document.getElementById('rrdtool_version').value != 'rrd-1.0.x') &&
+		(document.getElementById('color_id').selectedIndex != 0)) {
+		document.getElementById('alpha').disabled=false;
+	}
+}
+</script>
+<?php
+
+}
+?>
