@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004 Ian Berry                                            |
+ | Copyright (C) 2004-2010 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,14 +13,12 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | cacti: a php-based graphing solution                                    |
+ | Cacti: The Complete RRDTool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
- | Most of this code has been designed, written and is maintained by       |
- | Ian Berry. See about.php for specific developer credit. Any questions   |
- | or comments regarding this code should be directed to:                  |
- | - iberry@raxnet.net                                                     |
+ | This code is designed, written, and maintained by the Cacti Group. See  |
+ | about.php and/or the AUTHORS file for specific developer information.   |
  +-------------------------------------------------------------------------+
- | - raXnet - http://www.raxnet.net/                                       |
+ | http://www.cacti.net/                                                   |
  +-------------------------------------------------------------------------+
 */
 
@@ -125,8 +123,8 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 			when host.description is not null then ''
 			end,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') as name,
 			data_template_rrd.id
-			from data_template_data,data_template_rrd,data_local
-			left join host on data_local.host_id=host.id
+			from (data_template_data,data_template_rrd,data_local)
+			left join host on (data_local.host_id=host.id)
 			where data_template_rrd.local_data_id=data_local.id
 			and data_template_data.local_data_id=data_local.id
 			" . (empty($host_id) ? "" : " and data_local.host_id=$host_id") . "
@@ -139,7 +137,7 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 				$current_def_value = db_fetch_row("select
 					graph_templates_item." . $item["column_name"] . ",
 					graph_templates_item.id
-					from graph_templates_item,graph_template_input_defs
+					from (graph_templates_item,graph_template_input_defs)
 					where graph_template_input_defs.graph_template_item_id=graph_templates_item.local_graph_template_item_id
 					and graph_template_input_defs.graph_template_input_id=" . $item["id"] . "
 					and graph_templates_item.local_graph_id=$local_graph_id
@@ -148,7 +146,7 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 				$current_def_value = db_fetch_row("select
 					graph_templates_item." . $item["column_name"] . ",
 					graph_templates_item.id
-					from graph_templates_item,graph_template_input_defs
+					from (graph_templates_item,graph_template_input_defs)
 					where graph_template_input_defs.graph_template_item_id=graph_templates_item.id
 					and graph_template_input_defs.graph_template_input_id=" . $item["id"] . "
 					and graph_templates_item.graph_template_id=" . $graph_template_id . "
@@ -362,6 +360,14 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 				}
 
 				$draw_any_items = true;
+
+				/* if the "Output field" appears here among the non-templated fields, the
+				   valid choices for the drop-down box must be fetched from the associated
+				   data input method */
+				if ($field_name == "data_input_field_id") {
+					$data_input_id = db_fetch_cell("select data_input_id from data_template_data where data_template_id=".$rrd["data_template_id"]." and local_data_id=0");
+					$form_array[$form_field_name]["sql"] = "select id,CONCAT(data_name,' - ',name) as name from data_input_fields where data_input_id=".$data_input_id." and input_output='out' and update_rra='on' order by data_name,name";
+				}
 			}
 		}
 
@@ -397,13 +403,13 @@ function draw_nontemplated_fields_custom_data($data_template_data_id, $field_nam
 	global $colors;
 
 	$data = db_fetch_row("select id,data_input_id,data_template_id,name,local_data_id from data_template_data where id=$data_template_data_id");
-	$host_id = db_fetch_cell("select host.id from data_local,host where data_local.host_id=host.id and data_local.id=" . $data["local_data_id"]);
+	$host_id = db_fetch_cell("select host.id from (data_local,host) where data_local.host_id=host.id and data_local.id=" . $data["local_data_id"]);
 	$template_data = db_fetch_row("select id,data_input_id from data_template_data where data_template_id=" . $data["data_template_id"] . " and local_data_id=0");
 
 	$draw_any_items = false;
 
 	/* get each INPUT field for this data input source */
-	$fields = db_fetch_assoc("select * from data_input_fields where data_input_id=" . $data["data_input_id"] . " and input_output='in' order by name");
+	$fields = db_fetch_assoc("select * from data_input_fields where data_input_id=" . $data["data_input_id"] . " and input_output='in' order by sequence");
 
 	/* loop through each field found */
 	$i = 0;
@@ -481,14 +487,14 @@ function draw_custom_data_row($field_name, $data_input_field_id, $data_template_
 	if (($field["type_code"] == "index_type") && (db_fetch_cell("select local_data_id from data_template_data where id=$data_template_data_id") > 0)) {
 		$index_type = db_fetch_assoc("select
 			host_snmp_cache.field_name
-			from data_template_data,data_local,host_snmp_cache
+			from (data_template_data,data_local,host_snmp_cache)
 			where data_template_data.local_data_id=data_local.id
 			and data_local.snmp_query_id=host_snmp_cache.snmp_query_id
 			and data_template_data.id=$data_template_data_id
 			group by host_snmp_cache.field_name");
 
 		if (sizeof($index_type) == 0) {
-			print "<em>Data query data sources must be created through <a href='graphs_new.php'>New Graphs</a>.</em>\n";
+			print "<em>Data query data sources must be created through <a href='" . htmlspecialchars("graphs_new.php") . "'>New Graphs</a>.</em>\n";
 		}else{
 			form_dropdown($field_name, $index_type, "field_name", "field_name", $current_value, "", "", "");
 		}
@@ -496,14 +502,14 @@ function draw_custom_data_row($field_name, $data_input_field_id, $data_template_
 		$output_type = db_fetch_assoc("select
 			snmp_query_graph.id,
 			snmp_query_graph.name
-			from data_template_data,data_local,snmp_query_graph
+			from (data_template_data,data_local,snmp_query_graph)
 			where data_template_data.local_data_id=data_local.id
 			and data_local.snmp_query_id=snmp_query_graph.snmp_query_id
 			and data_template_data.id=$data_template_data_id
 			group by snmp_query_graph.id");
 
 		if (sizeof($output_type) == 0) {
-			print "<em>Data query data sources must be created through <a href='graphs_new.php'>New Graphs</a>.</em>\n";
+			print "<em>Data query data sources must be created through <a href='" . htmlspecialchars("graphs_new.php") . "'>New Graphs</a>.</em>\n";
 		}else{
 			form_dropdown($field_name, $output_type, "name", "id", $current_value, "", "", "");
 		}
